/************************************************************************************
*  Copyright (c), 2019, HelTec Automatic(TM) Technology co.,LTD.
*            All rights reserved.
*
* Http:    www.heltec.cn
* Email:   suppor@heltec.cn
* WebShop: heltec.taobao.com
*
* File name: main.c
* Processor: STM32F103VBT6
* Compiler : MDK fo ARM 5.26
* 
* Author : Aaron.Lee
* Version: 1.00
* Date   : 2019.3.4
* Email  : suppor@heltec.cn
* Modification: none
* 
* Description: Heltec 2.13" 200*200 Black-White-Red E-Ink driver code
*
* Others: none;
*
* Function List:
*	1. void EPD_W21_WriteCMD(uint8_t command); 			// Write Command via hardware SPI bus;
* 2. void EPD_W21_WriteDATA(uint8_t command); 		// Write data to E-Ink driver;
* 3. void WriteBuffer(unsigned  char *picture);   // Write a picture data to display buffer;
* 4. void DisplayRefresh(void); 									// Refresh display, must run this function after WriteBuffer;
* 5. void CheckStatus(void);											// Check busy;
* 6. void Display_Init(void);											// Initial display.
*
* History: none;
*
*************************************************************************************/

#include "e_ink_213_BWR.h"

#include "stm32f1xx.h"

extern SPI_HandleTypeDef hspi1;


 void EPD_W21_WriteCMD(uint8_t command)
{
  HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_RESET);                  
	HAL_GPIO_WritePin(GPIOE, DC, GPIO_PIN_RESET);		// command write
	HAL_SPI_Transmit(&hspi1,&command,sizeof(command),100);
	HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_SET);
}
	
 void EPD_W21_WriteDATA(uint8_t command)
{
  HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_RESET);                  
	HAL_GPIO_WritePin(GPIOE, DC, GPIO_PIN_SET);			// command write
	HAL_SPI_Transmit(&hspi1,&command,sizeof(command),100);
	HAL_GPIO_WritePin(GPIOD, CS, GPIO_PIN_SET);
}

void CheckStatus(void)
{
	while(1)
	{	 
		if(HAL_GPIO_ReadPin(GPIOE, BUSY)==1) break;
	}   
	HAL_Delay(100);                       
}

void Display_Init(void)
{		
	  HAL_Delay(100);
		
		//CheckStatus();
		EPD_W21_WriteCMD(0x12); // soft reset
		//CheckStatus();

		EPD_W21_WriteCMD(0x74); //set analog block control       
		EPD_W21_WriteDATA(0x54);
		EPD_W21_WriteCMD(0x7E); //set digital block control          
		EPD_W21_WriteDATA(0x3B);

		EPD_W21_WriteCMD(0x01); //Driver output control      
		EPD_W21_WriteDATA(0xF9);
		EPD_W21_WriteDATA(0x00);
		EPD_W21_WriteDATA(0x00);

		EPD_W21_WriteCMD(0x11); //data entry mode       
		EPD_W21_WriteDATA(0x01);

		EPD_W21_WriteCMD(0x44); //set Ram-X address start/end position   
		EPD_W21_WriteDATA(0x01);
		EPD_W21_WriteDATA(0x10);    //0x0F-->(15+1)*8=128

		EPD_W21_WriteCMD(0x45); //set Ram-Y address start/end position          
		EPD_W21_WriteDATA(0xF9);   //0xF9-->(249+1)=250
		EPD_W21_WriteDATA(0x00);
		EPD_W21_WriteDATA(0x00);
		EPD_W21_WriteDATA(0x00); 

		EPD_W21_WriteCMD(0x3C); //BorderWavefrom
		EPD_W21_WriteDATA(0x01);	

		EPD_W21_WriteCMD(0x18); 
		EPD_W21_WriteDATA(0x80);	

		EPD_W21_WriteCMD(0x4E);   // set RAM x address count to 0;
		EPD_W21_WriteDATA(0x01);
		EPD_W21_WriteCMD(0x4F);   // set RAM y address count to 0xF9-->(249+1)=250;    
		EPD_W21_WriteDATA(0xF9);
		EPD_W21_WriteDATA(0x00);
		// Epaper_READBUSY();
		//CheckStatus();
}

void WriteBuffer(unsigned  char *picture)
{
	unsigned int i;
	for(i=0;i<4000;i++)
		EPD_W21_WriteDATA(picture[i]); //display black picture
//	HAL_Delay(1);
}

void DisplayRefresh(void)
{
	EPD_W21_WriteCMD(0x22); 
	EPD_W21_WriteDATA(0xF7);   
	EPD_W21_WriteCMD(0x20); 
}

/***********************************************************
						end file
***********************************************************/

